]> git.mxchange.org Git - friendica.git/blobdiff - index.php
Merge pull request #4331 from annando/other-hashtags
[friendica.git] / index.php
index c4ccc9ef24db8bda5837516c3f1a89987cfd2275..2f07fa9af98b6fc3ad2c2590582a9af9ff3598ee 100644 (file)
--- a/index.php
+++ b/index.php
@@ -13,7 +13,9 @@ use Friendica\BaseObject;
 use Friendica\Content\Nav;
 use Friendica\Core\Addon;
 use Friendica\Core\System;
+use Friendica\Core\Theme;
 use Friendica\Core\Config;
+use Friendica\Core\L10n;
 use Friendica\Core\Worker;
 use Friendica\Database\DBM;
 use Friendica\Model\Profile;
@@ -82,9 +84,9 @@ if (!$install) {
        $maintenance = Config::get('system', 'maintenance');
 }
 
-$lang = get_browser_language();
+$lang = L10n::getBrowserLanguage();
 
-load_translation_table($lang);
+L10n::loadTranslationTable($lang);
 
 /**
  * Important stuff we always need to do.
@@ -120,7 +122,7 @@ if (x($_SESSION, 'authenticated') && !x($_SESSION, 'language')) {
 
 if ((x($_SESSION, 'language')) && ($_SESSION['language'] !== $lang)) {
        $lang = $_SESSION['language'];
-       load_translation_table($lang);
+       L10n::loadTranslationTable($lang);
 }
 
 if ((x($_GET, 'zrl')) && (!$install && !$maintenance)) {
@@ -179,7 +181,7 @@ if (! x($_SESSION, 'last_updated')) {
 /*
  * check_config() is responsible for running update scripts. These automatically
  * update the DB schema whenever we push a new one out. It also checks to see if
- * any plugins have been added or removed and reacts accordingly.
+ * any addons have been added or removed and reacts accordingly.
  */
 
 // in install mode, any url loads install module
@@ -191,7 +193,7 @@ if ($install && $a->module!="view") {
 } else {
        check_url($a);
        check_db(false);
-       check_plugins($a);
+       check_addons($a);
 }
 
 Nav::setSelected('nothing');
@@ -227,7 +229,7 @@ if (strlen($a->module)) {
 
        /**
         * We will always have a module name.
-        * First see if we have a plugin which is masquerading as a module.
+        * First see if we have an addon which is masquerading as a module.
         */
 
        // Compatibility with the Android Diaspora client
@@ -242,10 +244,10 @@ if (strlen($a->module)) {
 
        $privateapps = Config::get('config', 'private_addons');
 
-       if (is_array($a->plugins) && in_array($a->module, $a->plugins) && file_exists("addon/{$a->module}/{$a->module}.php")) {
+       if (is_array($a->addons) && in_array($a->module, $a->addons) && file_exists("addon/{$a->module}/{$a->module}.php")) {
                //Check if module is an app and if public access to apps is allowed or not
                if ((!local_user()) && Addon::isApp($a->module) && $privateapps === "1") {
-                       info(t("You must be logged in to use addons. "));
+                       info(L10n::t("You must be logged in to use addons. "));
                } else {
                        include_once "addon/{$a->module}/{$a->module}.php";
                        if (function_exists($a->module . '_module')) {
@@ -292,12 +294,12 @@ if (strlen($a->module)) {
                }
 
                logger('index.php: page not found: ' . $_SERVER['REQUEST_URI'] . ' ADDRESS: ' . $_SERVER['REMOTE_ADDR'] . ' QUERY: ' . $_SERVER['QUERY_STRING'], LOGGER_DEBUG);
-               header($_SERVER["SERVER_PROTOCOL"] . ' 404 ' . t('Not Found'));
+               header($_SERVER["SERVER_PROTOCOL"] . ' 404 ' . L10n::t('Not Found'));
                $tpl = get_markup_template("404.tpl");
                $a->page['content'] = replace_macros(
                        $tpl,
                        [
-                       '$message' =>  t('Page not found.')]
+                       '$message' =>  L10n::t('Page not found.')]
                );
        }
 }
@@ -415,8 +417,8 @@ if (isset($homebase)) {
  * now that we've been through the module content, see if the page reported
  * a permission problem and if so, a 403 response would seem to be in order.
  */
-if (stristr(implode("", $_SESSION['sysmsg']), t('Permission denied'))) {
-       header($_SERVER["SERVER_PROTOCOL"] . ' 403 ' . t('Permission denied.'));
+if (stristr(implode("", $_SESSION['sysmsg']), L10n::t('Permission denied'))) {
+       header($_SERVER["SERVER_PROTOCOL"] . ' 403 ' . L10n::t('Permission denied.'));
 }
 
 /*
@@ -444,7 +446,7 @@ if ($a->is_mobile || $a->is_tablet) {
                get_markup_template("toggle_mobile_footer.tpl"),
                [
                        '$toggle_link' => $link,
-                       '$toggle_text' => t('toggle mobile')]
+                       '$toggle_text' => L10n::t('toggle mobile')]
        );
 }
 
@@ -517,15 +519,15 @@ header('X-Frame-Options: sameorigin');
  * The page templates are located in /view/php/ or in the theme directory.
  */
 if (isset($_GET["mode"])) {
-       $template = theme_include($_GET["mode"] . '.php');
+       $template = Theme::getPathForFile($_GET["mode"] . '.php');
 }
 
 // If there is no page template use the default page template
 if (empty($template)) {
-       $template = theme_include("default.php");
+       $template = Theme::getPathForFile("default.php");
 }
 
/// @TODO Looks unsafe (remote-inclusion), is maybe not but theme_include() uses file_exists() but does not escape anything
 require_once $template;
 
 killme();
@@ -517,15 +519,15 @@ header('X-Frame-Options: sameorigin');
 }
 
-/// @TODO Looks unsafe (remote-inclusion), is maybe not but theme_include() uses file_exists() but does not escape anything
+/// @TODO Looks unsafe (remote-inclusion), is maybe not but Theme::getPathForFile() uses file_exists() but does not escape anything
 require_once $template;
 